
# Poetrip

[![image](https://img.shields.io/pypi/v/poetrip.svg)](https://pypi.org/project/poetrip/)
[![image](https://img.shields.io/pypi/l/poetrip.svg)](https://pypi.org/project/poetrip/)
[![image](https://img.shields.io/pypi/pyversions/poetrip.svg)](https://pypi.org/project/poetrip/)

Generate Pipfile from pyproject.toml.

## TODO:
- [x] Basic PyProject to Pipfile conversion
- [x] Fix scripts appearing in Pipfile
- [ ] Refactor structure and implement Pipfile to pyproject
